C$Procedure      POVTSM ( Output a smoothed triangle to a POV file )

      SUBROUTINE POVTSM ( FUNIT, PLTID, COLCH )

C$ Abstract
C
C     Output a smoothed colored triangle to a POV file.
C
C$ Copyright
C
C     Copyright (2002), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE MODEL
C
C$ Declarations

      IMPLICIT NONE

      INCLUDE              'pltmax.inc'

      INTEGER               PLTID
      INTEGER               FUNIT

      CHARACTER*(*)         COLCH

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FUNIT      I   Output file unit
C     PLTID      I   Plate ID
C     COLCH      I   Color
C
C$ Detailed_Input
C
C     FUNIT          is the output text file unit; must be attached to
C                    a text file opened for write access.
C
C     PLTID          is the plate ID.
C
C     COLCH          is a string specifying plate color; must be
C                    one of the 16 basic colors supported by POV
C                    ('gray', 'red', etc.)
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     Includes global plate model parameters, ``pltmax.inc''.
C
C$ Files
C
C     TBD.
C
C$ Exceptions
C
C     TBD.
C
C$ Particulars
C
C     TBD.
C
C$ Examples
C
C     See SPINPLAT program calling this routine.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof        (JPL)
C     B.V. Semenov      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPINPLAT Version 1.1.0, 25-AUG-2002 (BVS)
C
C        Added half-baked header. Added check in/out.
C
C-    SPINPLAT Version 1.0.0, DD-MMM-YYYY (JAB)
C
C        Initial version.
C
C-&

C
C     SPICELIB functions.
C
      LOGICAL               RETURN

C
C     Local declarations.
C
      INTEGER               I
      INTEGER               J
      INTEGER               NPLT
      INTEGER               VLOUT   ( 3 )
      INTEGER               PLIST   ( MAXEDG )

      DOUBLE PRECISION      PNRM    ( 3 )
      DOUBLE PRECISION      PTOT    ( 3 )
      DOUBLE PRECISION      VERT3   ( 3, 3 )
      DOUBLE PRECISION      PVNRM   ( 3, MAXEDG )

      CHARACTER*(400)       OUTLIN
      CHARACTER*(20)        VECT    ( 3 , 3 )
      CHARACTER*(20)        VECT2   ( 3 , 3 )

C
C     Check in.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF

      CALL CHKIN ( 'POVTSM' )

C
C     The code.
C

      OUTLIN = ' '

C
C     Get the coordinates of the plate's vertices.
C

      CALL NTHPLV ( PLTID, VERT3 )

C
C     Get the IDs of the plate's vertices.
C

      CALL NTHPVL ( PLTID, PLTID, VLOUT )

C
C     Determine the average normal vector at
C     each vertex.
C

      DO I = 1, 3

C
C     Get the plates that share a vertex.
C

         CALL VRTPLT ( VLOUT(I), NPLT, PLIST )


C
C     Average the normal vectors of all plates sharing
C     the same vertex.
C

         CALL VPACK ( 0.D0, 0.D0, 0.D0, PTOT )

         DO J = 1, NPLT
            CALL NTHPLN ( PLIST(J), PNRM )
            CALL VADD   ( PNRM, PTOT, PTOT )
         END DO

         CALL VSCL ( 1.D0/DBLE(NPLT), PTOT, PVNRM(1,I) )

      END DO

C
C     Write out data to POV file.
C

      DO I = 1, 3
         DO J = 1, 3
            CALL DPSTR ( VERT3(J,I), 8, VECT(J,I)  )
            CALL DPSTR ( PVNRM(J,I), 8, VECT2(J,I) )
         END DO
      END DO

      OUTLIN =   'smooth_triangle { <#,#,#>, <#,#,#>, '
     .        //                   '<#,#,#>, <#,#,#>, '
     .        //                   '<#,#,#>, <#,#,#> '
     .        //                   ' texture { # } }'


      DO I = 1, 3
         DO J = 1, 3
            CALL REPMC ( OUTLIN, '#', VECT(J,I),  OUTLIN )
         END DO
         DO J = 1, 3
            CALL REPMC ( OUTLIN, '#', VECT2(J,I), OUTLIN )
         END DO
      END DO

      CALL REPMC ( OUTLIN, '#', COLCH, OUTLIN )

      CALL WRITLN ( OUTLIN, FUNIT )

C
C     Check out.
C
      CALL CHKOUT ( 'POVTSM' )

      RETURN
      END

